@@ -51,7 +51,7 @@ VE.Jk.EB.SW2.Ratio <- function(VecY.s, VecX.s, VecPk.s, nII, VecPi.s, VecCluLab.
                                                     n,
                                                     VectVarEst = double(n),
                                                     PACKAGE = "samplingVarEst")$VectVarEst
-  SQVecPseudo.s                              <- ( (n-1)/n * (EstTheta - VecEstTheta_k) )^2
+  SQVecPseudo.s                              <- ( (1-1/n) * (EstTheta - VecEstTheta_k) )^2
   VectClusterSumSqPseudoValues               <- rowsum(SQVecPseudo.s, group = VecCluLab.s)
   VectPhiClu.sI                              <- VecPi.sI * nII/(nII -1) * (1 - nII/VecCluSize.sI)
   VarianceObservations                       <- sum(VectPhiClu.sI * VectClusterSumSqPseudoValues)
