@@ -23,7 +23,7 @@ VE.Jk.Tukey.RegCoI.Hajek <- function(VecY.s, VecX.s, VecPk.s, N, FPC= TRUE)
                                               VectVarEst = double(n),
                                               PACKAGE = "samplingVarEst")$VectVarEst
   EstTheta                             <- Est.RegCoI.Hajek(VecY.s, VecX.s, VecPk.s)
-  OUTPUT                               <- (Doublen-1)/Doublen * sum( (EstTheta - VecEstTheta_k) * (EstTheta - VecEstTheta_k) )
+  OUTPUT                               <- (Doublen-1/Doublen) * sum( (EstTheta - VecEstTheta_k) * (EstTheta - VecEstTheta_k) )
   if(FPC                              ){OUTPUT <- (1-Doublen/DoubleN) * OUTPUT                                                             }
   if(OUTPUT<0                         ){warning("The variance estimate contains negative values.")                                         }
   OUTPUT
